@@ -5,6 +5,7 @@
  */
 
 #include <QByteArray>
+#include <QString>
 #include <QtGlobal>
 
 #include "settingshelper.h"
@@ -16,6 +17,10 @@ inline bool parseQuickControlsMobile()
         return str == "1" || str == "true";
     }
 
+    if (qEnvironmentVariable("XDG_CURRENT_DESKTOP").contains(QStringLiteral("Phosh"), Qt::CaseInsensitive)) {
+        return true;
+    }
+
     return false;
 }
 
